@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from __future__ import annotations
+
 from typing import MutableMapping, MutableSequence
 
 from google.protobuf import field_mask_pb2  # type: ignore
@@ -859,8 +861,8 @@ class SearchLinksRequest(proto.Message):
 
     Attributes:
         parent (str):
-            Required. The project and location you want
-            search in.
+            Required. The project and location you want search in the
+            format ``projects/*/locations/*``
         source (google.cloud.datacatalog.lineage_v1.types.EntityReference):
             Optional. Send asset information in the **source** field to
             retrieve all links that lead from the specified asset to
@@ -1003,8 +1005,8 @@ class BatchSearchLinkProcessesRequest(proto.Message):
 
     Attributes:
         parent (str):
-            Required. The project and location where you
-            want to search.
+            Required. The project and location you want search in the
+            format ``projects/*/locations/*``
         links (MutableSequence[str]):
             Required. An array of links to check for their associated
             LineageProcesses.
@@ -1148,11 +1150,9 @@ class Origin(proto.Message):
             must match the project and location of the lineage resource
             being created. Examples:
 
-            -  {source_type: COMPOSER, name:
-               "projects/foo/locations/us/environments/bar"}
-            -  {source_type: BIGQUERY, name:
-               "projects/foo/locations/eu"}
-            -  {source_type: CUSTOM, name: "myCustomIntegration"}
+            -  ``{source_type: COMPOSER, name: "projects/foo/locations/us/environments/bar"}``
+            -  ``{source_type: BIGQUERY, name: "projects/foo/locations/eu"}``
+            -  ``{source_type: CUSTOM, name: "myCustomIntegration"}``
     """
 
     class SourceType(proto.Enum):
